@@ -1,5 +1,5 @@
-# coding: utf-8
-u"""Бэкенды для сервера ГАР ``m3-rest-gar``.
+"""
+Бэкенды для сервера ГАР ``m3-rest-gar``.
 
 https://stash.bars-open.ru/projects/M3/repos/m3-rest-gar
 """
