@@ -104,7 +104,7 @@ class AddressFields(BaseExtComponent):
         self._labels_text = {
             'place_name': 'Населенный пункт',
             'zip_code': 'Индекс',
-            'street_name': 'Улица',
+            'street_name': 'Улица/ЭПС',
             'house_number': 'Дом',
             'building_number': 'Корпус',
             'structure_number': 'Строение',
@@ -166,6 +166,7 @@ class AddressFields(BaseExtComponent):
             empty_text='Название субъекта/города/населенного пункта',
             read_only=self.read_only,
             allow_blank=self.allow_blank,
+            list_width=1000,
             fields=[
                 'objectId',
                 'level',
@@ -226,7 +227,7 @@ class AddressFields(BaseExtComponent):
             hide_trigger=True,
             force_selection=self.gar_only,
             min_chars=2,
-            empty_text='Название улицы/микрорайона',
+            empty_text='Название улицы/микрорайона/элемента планировочной структуры',
             read_only=self.read_only,
             fields=[
                 'objectId',
